<div align="center">
<img src="https://hpcflow.github.io/docs/stable/_static/images/logo-v2.png" width="250" alt="hpcFlow logo"/>
</div>

# hpcFlow

![PyPI - Version](https://img.shields.io/pypi/v/hpcflow-new2) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hpcflow-new2)

**hpcFlow manages your scientific workflows**

Documentation: [https://hpcflow.github.io/docs](https://hpcflow.github.io/docs)

## Acknowledgements

hpcFlow development is funded by [UKAEA](https://www.gov.uk/government/organisations/uk-atomic-energy-authority), and was initially developed using funding from the [LightForm](https://lightform.org.uk/) EPSRC programme grant ([EP/R001715/1](https://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/R001715/1)).

<img src="docs/source/_static/images/UKAEA_logo.png" width="90"/>
<br/><br/>
<img src="https://lightform-group.github.io/wiki/assets/images/site/lightform-logo.png" width="150"/>
